#! /usr/bin/env python

from setuptools import Command, Extension, setup
from setuptools.command.build_ext import build_ext


DISTNAME = "robo-base"
#DESCRIPTION = "primary base object"

if __name__ == "__main__":
    setup()
 
#mk  works

import robobase

#import robo_base as robobase

#


